#!/bin/bash
# Installation hdf5 and fcide decompression libs for MTG
# This script contains:
# . func_check()    : check only
# . funcdo_common() : install hdf5 lib
# . funcdo_fcide()  : install fcidecomp libs for MTG
#
# Only the func_check() is activated. This will not change anything, 
#   just checks if all libs are present.
#
# For installation:
#   either uncomment at the end of this file:
#     funcdo_common()
#     funcdo_fcide()
#   Or copy/paste the commands in these function, to do manual installation.
#   (root privilege necessary)

# For MTG you need to add in .profile: (without '#'!)
# export HDF5_PLUGIN_PATH=/usr/local/fcidecomp/hdf5/lib/plugin/

func_check()
{
  echo "Check installed libs"
  ls /usr/lib/libhdf5.so.9.0.0
  ls /usr/lib/libhdf5.so.9
  echo ""
  ls /usr/local/lib/libcharls.so.2.1.0
  ls /usr/local/lib/libcharls.so.2
  ls /usr/local/lib/libcharls.so
  echo ""
  ls /usr/lib/libhdf5.so.103.2.0
  ls /usr/lib/libhdf5.so.103
  echo ""
  ls /usr/local/fcidecomp/lib/libfcicomp_jpegls.so.1.0.1
  ls /usr/local/fcidecomp/lib/libfcicomp_jpegls.so.1
  ls /usr/local/fcidecomp/lib/libfcicomp_jpegls.so
  echo ""
  ls /usr/local/fcidecomp/hdf5/lib/plugin/libH5Zjpegls.so.2.0.0
  ls /usr/local/fcidecomp/hdf5/lib/plugin/libH5Zjpegls.so.2
  ls /usr/local/fcidecomp/hdf5/lib/plugin/libH5Zjpegls.so
  echo "End checks"
}

funcdo_common()
{
  sudo cp -p hdf5libs/libhdf5.so.9.0.0 /usr/lib/.
  sudo ln -s /usr/lib/libhdf5.so.9.0.0 /usr/lib/libhdf5.so.9
}

# Next libs are needed for MTG decompression. 
funcdo_fcide()
{
  sudo cp -p hdf5libs/libcharls.so.2.1.0 /usr/local/lib/.
  sudo ln -s /usr/local/lib/libcharls.so.2.1.0 /usr/local/lib/libcharls.so.2
  sudo ln -s /usr/local/lib/libcharls.so.2 /usr/local/lib/libcharls.so

  sudo cp -p hdf5libs/libhdf5.so.103.2.0  /usr/lib/.
  sudo ln -s /usr/lib/libhdf5.so.103.2.0 /usr/lib/libhdf5.so.103

  sudo mkdir -p /usr/local/fcidecomp/lib
  sudo cp -p hdf5libs/libfcicomp_jpegls.so.1.0.1 /usr/local/fcidecomp/lib/.
  sudo ln -s /usr/local/fcidecomp/lib/libfcicomp_jpegls.so.1.0.1 /usr/local/fcidecomp/lib/libfcicomp_jpegls.so.1
  sudo ln -s /usr/local/fcidecomp/lib/libfcicomp_jpegls.so.1 /usr/local/fcidecomp/lib/libfcicomp_jpegls.so

  # Make directory for decompression plugin and copy plugin
  sudo mkdir -p /usr/local/fcidecomp/hdf5/lib/plugin
  sudo cp -p hdf5libs/plugin/libH5Zjpegls.so.2.0.0 /usr/local/fcidecomp/hdf5/lib/plugin/.
  sudo ln -s /usr/local/fcidecomp/hdf5/lib/plugin/libH5Zjpegls.so.2.0.0 /usr/local/fcidecomp/hdf5/lib/plugin/libH5Zjpegls.so.2
  sudo ln -s /usr/local/fcidecomp/hdf5/lib/plugin/libH5Zjpegls.so.2 /usr/local/fcidecomp/hdf5/lib/plugin/libH5Zjpegls.so
}


# Run check
func_check

# Uncommented would install all libs, at your own risc... 
# Or use copy/paste of commands in these funcs to make sure you know what happens.

#funcdo_common
#funcdo_fcide

exit

